@@ -66,7 +66,9 @@ const char *nodeinfo_2_0_template = ""
     "\"services\":{\"outbound\":[],\"inbound\":[]},"
     "\"usage\":{\"users\":{\"total\":%d,\"activeMonth\":%d,\"activeHalfyear\":%d},"
     "\"localPosts\":%d},"
-    "\"openRegistrations\":false,\"metadata\":{}}";
+    "\"openRegistrations\":false,\"metadata\":{"
+    "\"nodeDescription\":\"%s\",\"nodeName\":\"%s\""
+    "}}";
 
 xs_str *nodeinfo_2_0(void)
 /* builds a nodeinfo json object */
@@ -99,7 +101,10 @@ xs_str *nodeinfo_2_0(void)
         n_posts += index_len(pidxfn);
     }
 
-    return xs_fmt(nodeinfo_2_0_template, n_utotal, n_umonth, n_uhyear, n_posts);
+    const char *name = xs_dict_get_def(srv_config, "title", "");
+    const char *desc = xs_dict_get_def(srv_config, "short_description", "");
+
+    return xs_fmt(nodeinfo_2_0_template, n_utotal, n_umonth, n_uhyear, n_posts, desc, name);
 }
 
 
@@ -221,7 +226,7 @@ int server_get_handler(xs_dict *req, const char *q_path,
         const xs_dict *q_vars = xs_dict_get(req, "q_vars");
         const char *t = NULL;
 
-        if (xs_type(q_vars) == XSTYPE_DICT && (t = xs_dict_get(q_vars, "t"))) {
+        if (xs_type(q_vars) == XSTYPE_DICT && xs_is_string(t = xs_dict_get(q_vars, "t"))) {
             /** search by tag **/
             int skip = 0;
             int show = xs_number_get(xs_dict_get_def(srv_config, "def_timeline_entries",
@@ -278,9 +283,10 @@ int server_get_handler(xs_dict *req, const char *q_path,
         status = HTTP_STATUS_OK;
         *ctype = "application/json; charset=utf-8";
         *body  = xs_fmt("{\"links\":["
-            "{\"rel\":\"http:/" "/nodeinfo.diaspora.software/ns/schema/2.0\","
-            "\"href\":\"%s/nodeinfo_2_0\"}]}",
-            srv_baseurl);
+            "{\"rel\":\"http:/" "/nodeinfo.diaspora.software/ns/schema/2.0\",\"href\":\"%s/nodeinfo_2_0\"},"
+            "{\"rel\":\"http:/" "/nodeinfo.diaspora.software/ns/schema/2.1\",\"href\":\"%s/nodeinfo_2_1\"}"
+            "]}",
+            srv_baseurl, srv_baseurl);
     }
     else
     if (strcmp(q_path, "/.well-known/host-meta") == 0) {
@@ -298,6 +304,19 @@ int server_get_handler(xs_dict *req, const char *q_path,
         *body  = nodeinfo_2_0();
     }
     else
+    if (strcmp(q_path, "/nodeinfo_2_1") == 0) {
+        xs *s = nodeinfo_2_0();
+        xs *j = xs_json_loads(s);
+
+        j = xs_dict_set(j, "version", "2.1");
+        j = xs_dict_set_path(j, "software.repository", WHAT_IS_SNAC_URL);
+        j = xs_dict_set_path(j, "software.homepage", SNAC_DOC_URL);
+
+        status = HTTP_STATUS_OK;
+        *ctype = "application/json; charset=utf-8";
+        *body  = xs_json_dumps(j, 4);
+    }
+    else
     if (strcmp(q_path, "/robots.txt") == 0) {
         status = HTTP_STATUS_OK;
         *ctype = "text/plain";
